@@ -1,9 +1,9 @@
 package Eixo::Queue::Mongo;
 
 use strict;
-use Eixo::Queue;
+
+use Eixo::Base::Clase qw(Eixo::Queue);
 use Eixo::Queue::MongoDriver;
-use parent qw(Eixo::Queue);
 
 has(
 
